@@ -3,6 +3,8 @@ from tests.testFactory import TestFactory
 from tests.testData import TestData
 from tests.testOutput import TestExport
 from tests.testCryptography import TestFernetFactory, TestDatabaseBaseSercure
+from tests.testGetSet import TestGetSet
+from tests.testDataFile import TestDataFile
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
